@@ -28,7 +28,7 @@ int get_dvd_name(const char *device, char *title)
   /* title is actually in the device name */
   char *new_title;
   new_title = strstr( device, "d0/" ) + strlen( "d0/" );
-  strncpy( title, new_title, 255 );
+  strncpy( title, new_title, sizeof(title)-1 );
 #else
   int  filehandle = 0;
   int  i = 0, last = 0;
@@ -41,37 +41,34 @@ int get_dvd_name(const char *device, char *title)
   if ( !(filehandle = open(device, O_RDONLY, 0)) )       
   {
       /* open failed */
-      fprintf( stderr, "[Error] Something went wrong while getting the dvd name  - please specify path as /cdrom or /dvd (mount point) or use -t\n");
-      fprintf( stderr, "[Error] Opening of the device failed\n");
-      fprintf( stderr, "[Error] Error: %s\n", strerror( errno ) );
+      fprintf( stderr, _("[Error] Something went wrong while getting the dvd name  - please specify path as /cdrom or /dvd (mount point) or use -t\n"));
+      fprintf( stderr, _("[Error] Opening of the device failed\n"));
+      fprintf( stderr, _("[Error] Error: %s\n"), strerror( errno ) );
       return -1;
   }
   
   /* seek to title of first track, which is at (track_no * 32768) + 40 */
-//  if ( 32808 != lseek( filehandle, 32808, SEEK_SET ) ) 
   if ( 32768 != lseek( filehandle, 32768, SEEK_SET ) )      
   {
       /* seek failed */
       close( filehandle );
-      fprintf( stderr, "[Error] Something went wrong while getting the dvd name - please specify path as /cdrom or /dvd (mount point) or use -t\n");
-      fprintf( stderr, "[Error] Couldn't seek into the drive\n");
-      fprintf( stderr, "[Error] Error: %s\n", strerror( errno ) );
+      fprintf( stderr, _("[Error] Something went wrong while getting the dvd name - please specify path as /cdrom or /dvd (mount point) or use -t\n"));
+      fprintf( stderr, _("[Error] Couldn't seek into the drive\n"));
+      fprintf( stderr, _("[Error] Error: %s\n"), strerror( errno ) );
       return -1;
   }
   
   /* read title */
-//  if ( (bytes_read = read(filehandle, title, 32)) != 32) 
   if ( (bytes_read = read(filehandle, tmp_buf, 2048)) != 2048 )      
   {
       close(filehandle);
-      fprintf( stderr, "[Error] something wrong in dvd_name getting - please specify path as /cdrom or /dvd (mount point) or use -t\n" );
-      fprintf( stderr, "[Error] only read %d bytes instead of 2048\n", bytes_read);
-      fprintf( stderr, "[Error] error: %s\n", strerror( errno ) );
+      fprintf( stderr, _("[Error] something wrong in dvd_name getting - please specify path as /cdrom or /dvd (mount point) or use -t\n") );
+      fprintf( stderr, _("[Error] only read %d bytes instead of 2048\n"), bytes_read);
+      fprintf( stderr, _("[Error] error: %s\n"), strerror( errno ) );
       return -1;
   }
   
   strncpy( title, &tmp_buf[40], 32 ); 
-//   memcpy(title, help + 40, 32);
    
   /* make sure string is terminated */
   title[32] = '\0';
@@ -85,7 +82,7 @@ int get_dvd_name(const char *device, char *title)
   }
   if( 0 == last )
       {
-          fprintf( stderr, "[Hint] The dvd has no name, will choose a nice one ;-), else use -t\n" );
+          fprintf( stderr, _("[Hint] The dvd has no name, will choose a nice one ;-), else use -t\n") );
           strcpy( title, "insert_name_here\0" );
       }
   else
@@ -115,12 +112,17 @@ int get_device( char *path, char *device )
   struct mntent* lmount_entry;
 #endif
 
+#if ( defined( __sun ) )
   FILE  *mnttab_fp;
+  char *mnt_special;
+  int mntcheck;
+  char *new_device;
+#endif
+
   char  *pointer;
-  char *new_device, *mnt_special;
   char  *k;
   bool  mounted = FALSE;
-  int mntcheck;
+
 #ifdef USE_STATFS_FOR_DEV
   struct statfs buf;
 #endif
@@ -176,7 +178,7 @@ int get_device( char *path, char *device )
       }
     else
       {
-       fprintf( stderr, "[Error] Error while reading filesystem info" );
+       fprintf( stderr, _("[Error] Error while reading filesystem info") );
        return -1;
       }
 #elif ( defined( __sun ) )
@@ -186,8 +188,8 @@ int get_device( char *path, char *device )
  
     if ( ( mnttab_fp = fopen( "/etc/mnttab", "r" ) ) == NULL )
       {
-	fprintf( stderr, " [Error] Could not open mnttab for searching!\n" );
-	fprintf( stderr, " [Error] error: %s\n", strerror( errno ) );
+	fprintf( stderr, _(" [Error] Could not open mnttab for searching!\n") );
+	fprintf( stderr, _(" [Error] error: %s\n"), strerror( errno ) );
 	return -1;
       }
 
@@ -199,7 +201,7 @@ int get_device( char *path, char *device )
 	    char *new_device, *mnt_special;
 	    if ( strstr( mount_entry.mnt_special, "/dsk/" ) == NULL )
 	      {
-		fprintf( stderr, "[Error] %s doesn't look like a disk device to me",
+		fprintf( stderr, _("[Error] %s doesn't look like a disk device to me"),
 			 mount_entry.mnt_special );
 		return -1;
 	      }
@@ -213,7 +215,7 @@ int get_device( char *path, char *device )
 	    strcat( new_device, "/rdsk/" );
 	    strcat( new_device,
 		    strstr( mnt_special, "/dsk/" ) + strlen( "/dsk/" ) );
-	    strncpy( device, new_device, 255 );
+	    strncpy( device, new_device, sizeof(device)-1 );
 	    free( mnt_special );
 	    free( new_device );
 	    mounted = TRUE;
@@ -222,13 +224,13 @@ int get_device( char *path, char *device )
       }
     if ( mntcheck > 0 )
       {
-         fprintf( stderr, "[Error] Encountered error in reading mnttab file\n" );
-         fprintf( stderr, "[Error] error: %s\n", strerror( errno ) );
+         fprintf( stderr, _("[Error] Encountered error in reading mnttab file\n") );
+         fprintf( stderr, _("[Error] error: %s\n"), strerror( errno ) );
          return -1;
       }
     else if ( mntcheck == -1 )
       {
-         fprintf( stderr, "[Error] Did not find mount %s in mnttab!\n", path );
+         fprintf( stderr, _("[Error] Did not find mount %s in mnttab!\n"), path );
          return -1;
       }
 #else
@@ -278,8 +280,8 @@ this is the code for the other-OSs, not solaris*/
       }
     else
       {
-	fprintf( stderr, "[Error] Could not read /etc/mtab!\n" );
-	fprintf( stderr, "[Error] error: %s\n", strerror( errno ) );
+	fprintf( stderr, _("[Error] Could not read /etc/mtab!\n") );
+	fprintf( stderr, _("[Error] error: %s\n"), strerror( errno ) );
 	return -1;
       }  
 #endif
@@ -311,7 +313,7 @@ this is the code for the other-OSs, not solaris*/
 
 		if( ( k = strstr( tmp_bufferin, "/dev/" ) ) == NULL )
 		  {
-		    fprintf( stderr, "[Error] Weird, no /dev/ entry found in the line where iso9660 or udf gets mentioned in /etc/fstab\n" );
+		    fprintf( stderr, _("[Error] Weird, no /dev/ entry found in the line where iso9660 or udf gets mentioned in /etc/fstab\n") );
 		    return -1;
 		  }
 		l=0;
@@ -327,7 +329,7 @@ this is the code for the other-OSs, not solaris*/
 		if( isdigit( ( int) device[l-1] ) )
 	          {
                  if( strstr( device, "hd" ) )
-	              fprintf(stderr, "[Hint] Hmm, the last char in the device path (%s) that gets mounted to %s is a number.\n", device, path);
+	              fprintf( stderr, _("[Hint] Hmm, the last char in the device path (%s) that gets mounted to %s is a number.\n"), device, path);
 	          }
 		device[l] = '\0';
 	      }
@@ -336,15 +338,15 @@ this is the code for the other-OSs, not solaris*/
           fclose( tmp_streamin );
 	  if( !strstr( device, "/dev" ) )
 	    {
-	      fprintf(stderr, "[Error] Could not find the provided path (%s), typo?\n",path);
+	      fprintf( stderr, _("[Error] Could not find the provided path (%s), typo?\n"),path);
 	      device[0] = '\0';
 	      return -1;
 	    }
       }
     else
       {
-	fprintf( stderr, "[Error] Could not read /etc/fstab!" );
-	fprintf( stderr, "[Error] error: %s\n", strerror( errno ) );
+	fprintf( stderr, _("[Error] Could not read /etc/fstab!") );
+	fprintf( stderr, _("[Error] error: %s\n"), strerror( errno ) );
 	device[0] = '\0';
 	return -1;
       }
@@ -387,13 +389,13 @@ int get_device_on_your_own( char *path, char *device )
         }
       if(dvd_count == 0)
         { /* no cd found? Then user should mount it */
-	  fprintf(stderr, "[Error] There seems to be no cd/dvd mounted. Please do that..\n");
+	  fprintf( stderr, _("[Error] There seems to be no cd/dvd mounted. Please do that..\n"));
 	  return -1;
         }
     }
   else
     {
-      fprintf(stderr, "[Error] An error occured while getting mounted file system information\n");
+      fprintf( stderr, _("[Error] An error occured while getting mounted file system information\n"));
       return -1;
     }
 
@@ -402,15 +404,15 @@ int get_device_on_your_own( char *path, char *device )
     /* Completely rewritten search of a mounted DVD on Solaris, much
      cleaner. No more parsing of strings -- lb */
 
-    // the mnttab file
+    /* the mnttab file */
     FILE         *mnttab_fp;
-    // The mount entry found
+    /* The mount entry found */
     struct mnttab mountEntry;
-    // The mount search fields
+    /* The mount search fields */
     struct mnttab udfsMount;
-    // Number of found entries
+    /* Number of found entries */
     int           dvd_count = 0;
-    // Result of the mount search
+    /* Result of the mount search */
     int           result    = 0;
 
 
@@ -424,28 +426,28 @@ int get_device_on_your_own( char *path, char *device )
 	   
     /* Try to open the mnttab info */
     if (( mnttab_fp = fopen( "/etc/mnttab", "r" ) ) == NULL) {
-      fprintf( stderr, "[Error] Could not open mnttab for searching!\n" );
-      fprintf( stderr, "[Error] error: %s\n", strerror( errno ) );
+      fprintf( stderr, _("[Error] Could not open mnttab for searching!\n") );
+      fprintf( stderr, _("[Error] error: %s\n"), strerror( errno ) );
       return -1;
 	     }
 
-    // Get the matching mount points
-    // If there is a match, handle it
+    /* Get the matching mount points */
+    /* If there is a match, handle it */
     while ((result = getmntany(mnttab_fp, &mountEntry, &udfsMount)) == 0) {
       dvd_count++;
 	 }
 
-    // If the last result is not -1, there was a problem -- exit
+    /* If the last result is not -1, there was a problem -- exit */
     if (result != -1)
       return -1;
    
-    // no cd found? Then user should mount it
+    /* no cd found? Then user should mount it */
     if (dvd_count == 0) {
-	 fprintf(stderr, "[Error] There seems to be no cd/dvd mounted. Please do that..\n");
+	 fprintf( stderr, _("[Error] There seems to be no cd/dvd mounted. Please do that..\n"));
 	 return -1;
        }
 
-    // Copy the device name and mount points to the output variables
+    /* Copy the device name and mount points to the output variables */
     strcpy(path,   mountEntry.mnt_mountp);
     strcpy(device, mountEntry.mnt_special);
 
@@ -479,7 +481,7 @@ int get_device_on_your_own( char *path, char *device )
 
 	   if( ( k = strstr( tmp_bufferin, "/dev/" ) ) == NULL )
 	     {
-	       fprintf( stderr, "[Error] Weird, no /dev/ entry found in the line where iso9660, udf or cdrom gets mentioned in /etc/mtab\n" );
+	       fprintf( stderr, _("[Error] Weird, no /dev/ entry found in the line where iso9660, udf or cdrom gets mentioned in /etc/mtab\n") );
 	       return -1;
 	     }
 
@@ -495,7 +497,7 @@ int get_device_on_your_own( char *path, char *device )
 	   if(isdigit((int)device[l-1]))
 	     {
                  if( strstr( device, "hd" ) )
-                    fprintf(stderr, "[Hint] Hmm, the last char in the device path %s is a number.\n", device );
+                    fprintf( stderr, _("[Hint] Hmm, the last char in the device path %s is a number.\n"), device );
 	     }
 	   
 	   /*The syntax of /etc/fstab and mtab seems to be something like this:
@@ -522,14 +524,23 @@ int get_device_on_your_own( char *path, char *device )
 	   */
 	   l=0;
 
-	   while(isgraph( (int) *(k) ))
-	     {
-	       path[l] = *(k);
-	       k++;
-	       l++;
-	     }
-	   path[l] = '\0';
 
+
+	     while(isgraph( (int) *(k) ))
+                                   {
+                                          if (!strncmp(k, "\\040", 4)) 
+                                          { /* replace escaped ASCII space ... */
+                                                   path[l++] = ' '; /* ... with literal space */
+                                                   k+=4;
+                                          }
+                                          else 
+                                          {
+                                                   path[l] = *(k);
+                                                   k++;
+                                                   l++;
+                                          }
+                                   }
+	     path[l] = '\0';
 	 }
        memset( tmp_bufferin, 0, MAX_STRING * sizeof( char ) );
        l = 0; /*for the next run
@@ -542,14 +553,14 @@ int get_device_on_your_own( char *path, char *device )
 
      if(dvd_count == 0)
        { /* no cd found? Then user should mount it */
-	 fprintf(stderr, "[Error] There seems to be no cd/dvd mounted. Please do that..\n");
+	 fprintf( stderr, _("[Error] There seems to be no cd/dvd mounted. Please do that..\n"));
 	 return -1;
        }
    }
  else
    {
-     fprintf(stderr, "[Error] Could not read /etc/mtab!");
-     fprintf( stderr, "[Error] error: %s\n", strerror( errno ) );
+     fprintf( stderr, _("[Error] Could not read /etc/mtab!"));
+     fprintf( stderr, _("[Error] error: %s\n"), strerror( errno ) );
      return -1;
    }
 #endif
@@ -566,9 +577,7 @@ off_t get_vob_size( int title, char *provided_input_dir )
             path_to_vobs1[278], 
             path_to_vobs2[278], 
             path_to_vobs3[278];
-      char  temp[278], 
-            temp1[3], 
-            stat_path[278];
+      char  stat_path[278];
       int   subvob;
       FILE  *tmp_streamin1;
       struct stat buf;
